@@ -57,7 +57,7 @@ SGD.MMD.beta = function(x, par1, par2, kernel, bdwth, burnin, nstep, stepsize, e
     par = par-stepsize*grad/sqrt(norm.grad)
     par[1] = max(par[1],1/n)
     par[2] = max(par[2],1/n)
-    trajectory = cbind(trajectory,par)
+    trajectory = cbind(trajectory,matrix(data=par,nrow=2,ncol=1))
   }
   
   # SGD period
@@ -75,7 +75,7 @@ SGD.MMD.beta = function(x, par1, par2, kernel, bdwth, burnin, nstep, stepsize, e
     par[1] = max(par[1],1/n)
     par[2] = max(par[2],1/n)
     par_mean = (par_mean*i + par)/(i+1)
-    trajectory = cbind(trajectory,par_mean)
+    trajectory = cbind(trajectory,matrix(data=par_mean,nrow=2,ncol=1))
   }
   
   # return
